# Computerlinguistische Analyse des Merlin Corpus (https://merlin-platform.eu/) mit CTAP
# Lösungen
#
# Zarah Weiss, 18.02.2020
# =============================================================================================

rm(list = ls())
library(tidyverse)
source("source.R")


# Laden Sie die Analysedatei, die CTAP generiert hat, und bringen Sie diese in das richtige Format
# =============================================================================================

# Datei laden
merlin.daten.im.langformat <- read_delim("merlin-th1-50.csv", delim = "\t", col_types = "nccncn")
# Meta-Informationen aus Dateinamen extrahieren und nicht benötigte Meta-Informationen entfernen
merlin.daten <- merlin.daten.vorbereitung(merlin.daten.im.langformat)

# Gewinnen Sie einen Überblick über Ihre Daten
str(merlin.daten)
# Begutachten Sie die Verteilung der Aufgaben
table(merlin.daten$Task.ID)
# Begutachten Sie die Verteilung der Kompetenzstufen
table(merlin.daten$CEFR.Score.Overall)
# Begutachten Sie die Verteilung der Erstsprachen
table(merlin.daten$L1)
# Begutachten Sie die Verteilung der Geschlechter
table(merlin.daten$Gender)


# Visuelle Inspektion der sprachlichen Entwicklung über Kompetenzlevel anhand von Oberflächenmaßen
# =============================================================================================

# Hier legen Sie den Namen des Merkmals fest sowie den Dateinamen, unter dem Sie den Plot speichern möchten.
aktueller.merkmalsname <- "Number of Tokens"
aktueller.dateiname <- "number_of_tokens.pdf"

# Generieren Sie Boxplots mit der Variable "Anzahl der Wörter und Zeichen"
# Diese Zeilen können Sie ausführen, um einen Boxplot zu erstellen
mein.beispielplot <- erstelle.boxplot(merlin.daten, aktueller.merkmalsname)

# Führen Sie die folgenden Zeile aus, um den Plot im Verzeichnis plots/ zu speichern.
speichere.boxplot(datei.name = aktueller.dateiname, aktueller.plot = mein.beispielplot)

# Um sich den Plot in RStudio anzusehen, führen Sie folgende Zeile aus
mein.beispielplot 


# Machen Sie sich einen Überblick über die durchschnittliche Satzlänge in Wörtern
# =============================================================================================

merkmalsnamen <- c("Number of Tokens", "Mean Sentence Length in Tokens", "Mean Token Length in Syllables",
                   "Lexical Richness: Type Token Ratio (TTR)", "Lexical Richness: Type Token Ratio (Uber)", 
                   "Lexical Variation Feature: Lexical", 
                   "Syntactic Complexity Feature: Verb Cluster per Clause", "Syntactic Complexity Feature: Dependent clause ratio",
                   "Syntactic Complexity Feature: Complex Nominals per Sentence",
                   "Syntactic Complexity Feature: Prenominal Modifier per Complex Noun Phrase",
                   "Lexical Sophistication Feature: SUBTLEX Word Frequency (AW Token)",
                   "Lexical Sophistication Feature: Mean Age of Active Use in KCT (AW Token)",
                   "Cohesive Complexity Feature: Breindl All Connectives per Token",
                   "Cohesive Complexity Feature: Breindl Adversative and Concessive Connectives per Token")

for (aktueller.merkmalsname in merkmalsnamen) {
  aktueller.dateiname <- paste0("plots-th1-50/",str_replace_all(aktueller.merkmalsname, pattern = " ", "_"), ".pdf")
  mein.beispielplot <- erstelle.boxplot(merlin.daten, aktueller.merkmalsname) 
  speichere.boxplot(datei.name = aktueller.dateiname, aktueller.plot = mein.beispielplot)  
}










