# Computerlinguistische Analyse des Merlin Corpus (https://merlin-platform.eu/) mit CTAP
# Skript zur erweiterten Datenanalyse
#
# Zarah Weiss, 18.02.2020
# =============================================================================================

rm(list = ls())
library(tidyverse)
source("source.R")


# Laden Sie die Analysedatei, die CTAP generiert hat, und bringen Sie diese in das richtige Format
# =============================================================================================

# Analyse der korrigierten Texte laden 
merlin.daten.im.langformat.korrigiert <- read_delim("merlin-th1-all.csv", delim = "\t", col_types = "nccncn")

# Analyse der nicht-korrigierten Texte laden
merlin.daten.im.langformat.nichtkorrigiert <- read_delim("merlin-orig-all.csv", delim = "\t", col_types = "nccncn")

# Kombination der korrigierten und nicht korrigierten Daten. Sie finden die Information, 
# ob es sich um korrigigierte Daten handelt oder nicht in der binären Variable Wurde.Korrigiert
merlin.daten <- merlin.daten.vorbereitung2(merlin.daten.im.langformat.korrigiert, merlin.daten.im.langformat.nichtkorrigiert)

# Untersuchung von Aufgabeneffekten auf Merkmale sprachlicher Komplexität
# =============================================================================================

merkmalsnamen <- c("Number of Tokens", "Mean Sentence Length in Tokens", "Mean Token Length in Syllables",
                   "Lexical Richness: Type Token Ratio (TTR)", "Lexical Variation Feature: Lexical", 
                   "Lexical Richness: Type Token Ratio (Uber)", 
                   "Syntactic Complexity Feature: Verb Cluster per Clause", "Syntactic Complexity Feature: Dependent clause ratio",
                   "Syntactic Complexity Feature: Complex Nominals per Sentence",
                   "Syntactic Complexity Feature: Prenominal Modifier per Complex Noun Phrase",
                   "Lexical Sophistication Feature: SUBTLEX Word Frequency (AW Token)",
                   "Lexical Sophistication Feature: Mean Age of Active Use in KCT (AW Token)",
                   "Cohesive Complexity Feature: Breindl All Connectives per Token",
                   "Cohesive Complexity Feature: Breindl Adversative and Concessive Connectives per Token")

for (aktueller.merkmalsname in merkmalsnamen) {
  aktueller.dateiname <- paste0("plots-korrektureffekte/",str_replace_all(aktueller.merkmalsname, pattern = " ", "_"), ".pdf")
  mein.beispielplot <- erstelle.boxplot.korrigiert.nichtkorrigiert(merlin.daten, aktueller.merkmalsname) 
  speichere.boxplot(datei.name = aktueller.dateiname, aktueller.plot = mein.beispielplot)  
}


# Untersuchung von Aufgabenunterschieden in den korrigierten oder nicht-korrigierten Daten
# =============================================================================================

for (aktueller.merkmalsname in merkmalsnamen) {
  aktueller.dateiname <- paste0("plots-aufgabeneffekte/",str_replace_all(aktueller.merkmalsname, pattern = " ", "_"), ".pdf")
  mein.beispielplot <- erstelle.boxplot.mit.aufgabensplit(merlin.daten[merlin.daten$Wurde.Korrigiert,], aktueller.merkmalsname)
  speichere.boxplot(datei.name = aktueller.dateiname, aktueller.plot = mein.beispielplot)  
}








